import { NFTMetadata, NFTMetadataOrUri } from "../../core/schema/nft";
import type { Weiweb3Storage, UploadProgressEvent } from "@weiweb3/storage";
import { BigNumberish, providers } from "ethers";
export declare const FALLBACK_METADATA: {
    name: string;
};
/**
 * fetches the token metadata
 * @param tokenId - the id (to get it back in the output)
 * @param tokenUri - the uri to fetch
 * @param storage - which storage to fetch from
 *
 * @internal
 */
export declare function fetchTokenMetadata(tokenId: BigNumberish, tokenUri: string, storage: Weiweb3Storage): Promise<NFTMetadata>;
/**
 * @internal
 * @param contractAddress
 * @param provider
 * @param tokenId
 * @param storage
 */
export declare function fetchTokenMetadataForContract(contractAddress: string, provider: providers.Provider, tokenId: BigNumberish, storage: Weiweb3Storage): Promise<{
    [x: string]: unknown;
    name?: string | number | undefined;
    description?: string | null | undefined;
    image?: string | null | undefined;
    external_url?: string | null | undefined;
    animation_url?: string | null | undefined;
    background_color?: string | undefined;
    properties?: {
        [x: string]: unknown;
    } | {
        [x: string]: unknown;
    }[] | undefined;
    attributes?: {
        [x: string]: unknown;
    } | {
        [x: string]: unknown;
    }[] | undefined;
    id: string;
    uri: string;
}>;
/**
 * @internal
 * @param metadata
 * @param storage
 */
export declare function uploadOrExtractURI(metadata: NFTMetadataOrUri, storage: Weiweb3Storage): Promise<string>;
/**
 * @internal
 * @param metadatas
 * @param storage
 * @param startNumber
 * @param contractAddress
 * @param signerAddress
 * @param options
 */
export declare function uploadOrExtractURIs(metadatas: NFTMetadataOrUri[], storage: Weiweb3Storage, startNumber?: number, options?: {
    onProgress: (event: UploadProgressEvent) => void;
}): Promise<string[]>;
export declare function getBaseUriFromBatch(uris: string[]): string;
//# sourceMappingURL=nft.d.ts.map