import { _ as _defineProperty } from './QueryParams-536ff1cc.esm.js';
import { aE as StandardErc721, cm as ContractWrapper, ag as ContractMetadata, cy as TokenErc721ContractSchema, ah as ContractRoles, ai as ContractRoyalty, aj as ContractPrimarySale, af as ContractEncoder, aQ as GasCostEstimator, aR as ContractEvents, aT as ContractPlatformFee, aS as ContractInterceptor, av as Erc721, ay as Erc721WithQuantitySignatureMintable, aV as ContractOwner, br as getRoleHash } from './paper-xyz-9928d271.esm.js';
import { constants } from 'ethers';
import 'bn.js';
import 'zod';
import '@weiweb3/contracts-js/dist/abis/IERC165.json';
import '@weiweb3/contracts-js/dist/abis/IERC721.json';
import '@weiweb3/contracts-js/dist/abis/IERC1155.json';
import 'tiny-invariant';
import 'eventemitter3';
import 'cross-fetch';
import '@weiweb3/contracts-js/dist/abis/Forwarder.json';
import '@weiweb3/contracts-js/dist/abis/IBurnableERC20.json';
import '@weiweb3/contracts-js/dist/abis/IDropSinglePhase.json';
import '@weiweb3/contracts-js/dist/abis/IERC20.json';
import '@weiweb3/contracts-js/dist/abis/IMintableERC20.json';
import '@weiweb3/contracts-js/dist/abis/IMulticall.json';
import '@weiweb3/contracts-js/dist/abis/ISignatureMintERC20.json';
import '@weiweb3/contracts-js/dist/abis/IBurnableERC721.json';
import '@weiweb3/contracts-js/dist/abis/IClaimableERC721.json';
import '@weiweb3/contracts-js/dist/abis/IDelayedReveal.json';
import '@weiweb3/contracts-js/dist/abis/IERC721Enumerable.json';
import '@weiweb3/contracts-js/dist/abis/IERC721Supply.json';
import '@weiweb3/contracts-js/dist/abis/ILazyMint.json';
import '@weiweb3/contracts-js/dist/abis/IMintableERC721.json';
import '@weiweb3/contracts-js/dist/abis/SignatureMintERC721.json';
import '@weiweb3/contracts-js/dist/abis/DelayedReveal.json';
import '@weiweb3/contracts-js/dist/abis/DropSinglePhase1155.json';
import '@weiweb3/contracts-js/dist/abis/IBurnableERC1155.json';
import '@weiweb3/contracts-js/dist/abis/IClaimableERC1155.json';
import '@weiweb3/contracts-js/dist/abis/IERC1155Enumerable.json';
import '@weiweb3/contracts-js/dist/abis/IMintableERC1155.json';
import '@weiweb3/contracts-js/dist/abis/ISignatureMintERC1155.json';
import 'bs58';
import 'cbor-x';
import '@weiweb3/contracts-js/dist/abis/IERC20Metadata.json';
import 'merkletreejs';
import 'fast-deep-equal';
import 'uuid';
import '@weiweb3/contracts-js/dist/abis/IERC721Metadata.json';
import '@weiweb3/contracts-js/dist/abis/IERC1155Metadata.json';
import '@weiweb3/contracts-js/dist/abis/IDelayedRevealDeprecated.json';
import '@weiweb3/contracts-js/dist/abis/TWFactory.json';
import '@weiweb3/contracts-js/dist/abis/TWRegistry.json';
import '@weiweb3/contracts-js/dist/abis/ContractPublisher.json';
import '@weiweb3/contracts-js/dist/abis/IWeiweb3Contract.json';
import '@weiweb3/storage';
import '@weiweb3/contracts-js/dist/abis/IAppURI.json';
import '@weiweb3/contracts-js/dist/abis/IContractMetadata.json';
import '@weiweb3/contracts-js/dist/abis/IPermissions.json';
import '@weiweb3/contracts-js/dist/abis/IPermissionsEnumerable.json';
import '@weiweb3/contracts-js/dist/abis/IPlatformFee.json';
import '@weiweb3/contracts-js/dist/abis/IPrimarySale.json';
import '@weiweb3/contracts-js/dist/abis/IRoyalty.json';
import '@weiweb3/contracts-js/dist/abis/Ownable.json';

/**
 * Create a collection of one-of-one NFTs.
 *
 * @example
 *
 * ```javascript
 * import { Weiweb3SDK } from "@weiweb3/sdk";
 *
 * const sdk = new Weiweb3SDK("{{chainName}}");
 * const contract = sdk.getContract("{{contract_address}}", "nft-collection");
 * ```
 *
 * @public
 */

class NFTCollection extends StandardErc721 {
  /**
   * Configure royalties
   * @remarks Set your own royalties for the entire contract or per token
   * @example
   * ```javascript
   * // royalties on the whole contract
   * contract.royalties.setDefaultRoyaltyInfo({
   *   seller_fee_basis_points: 100, // 1%
   *   fee_recipient: "0x..."
   * });
   * // override royalty for a particular token
   * contract.royalties.setTokenRoyaltyInfo(tokenId, {
   *   seller_fee_basis_points: 500, // 5%
   *   fee_recipient: "0x..."
   * });
   * ```
   */

  /**
   * Signature Minting
   * @remarks Generate dynamic NFTs with your own signature, and let others mint them using that signature.
   * @example
   * ```javascript
   * // see how to craft a payload to sign in the `contract.signature.generate()` documentation
   * const signedPayload = contract.signature().generate(payload);
   *
   * // now anyone can mint the NFT
   * const tx = contract.signature.mint(signedPayload);
   * const receipt = tx.receipt; // the mint transaction receipt
   * const mintedId = tx.id; // the id of the NFT minted
   * ```
   */

  /**
   * @internal
   */
  constructor(network, address, storage) {
    let options = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : {};
    let abi = arguments.length > 4 ? arguments[4] : undefined;
    let chainId = arguments.length > 5 ? arguments[5] : undefined;
    let contractWrapper = arguments.length > 6 && arguments[6] !== undefined ? arguments[6] : new ContractWrapper(network, address, abi, options);
    super(contractWrapper, storage, chainId);

    _defineProperty(this, "abi", void 0);

    _defineProperty(this, "metadata", void 0);

    _defineProperty(this, "roles", void 0);

    _defineProperty(this, "encoder", void 0);

    _defineProperty(this, "estimator", void 0);

    _defineProperty(this, "events", void 0);

    _defineProperty(this, "sales", void 0);

    _defineProperty(this, "platformFees", void 0);

    _defineProperty(this, "royalties", void 0);

    _defineProperty(this, "owner", void 0);

    _defineProperty(this, "signature", void 0);

    _defineProperty(this, "interceptor", void 0);

    _defineProperty(this, "erc721", void 0);

    this.abi = abi;
    this.metadata = new ContractMetadata(this.contractWrapper, TokenErc721ContractSchema, this.storage);
    this.roles = new ContractRoles(this.contractWrapper, NFTCollection.contractRoles);
    this.royalties = new ContractRoyalty(this.contractWrapper, this.metadata);
    this.sales = new ContractPrimarySale(this.contractWrapper);
    this.encoder = new ContractEncoder(this.contractWrapper);
    this.estimator = new GasCostEstimator(this.contractWrapper);
    this.events = new ContractEvents(this.contractWrapper);
    this.platformFees = new ContractPlatformFee(this.contractWrapper);
    this.interceptor = new ContractInterceptor(this.contractWrapper);
    this.erc721 = new Erc721(this.contractWrapper, this.storage, chainId);
    this.signature = new Erc721WithQuantitySignatureMintable(this.contractWrapper, this.storage);
    this.owner = new ContractOwner(this.contractWrapper);
  }
  /**
   * @internal
   */


  onNetworkUpdated(network) {
    this.contractWrapper.updateSignerOrProvider(network);
  }

  getAddress() {
    return this.contractWrapper.readContract.address;
  }
  /** ******************************
   * READ FUNCTIONS
   *******************************/

  /**
   * Get whether users can transfer NFTs from this contract
   */


  async isTransferRestricted() {
    const anyoneCanTransfer = await this.contractWrapper.readContract.hasRole(getRoleHash("transfer"), constants.AddressZero);
    return !anyoneCanTransfer;
  }
  /** ******************************
   * WRITE FUNCTIONS
   *******************************/

  /**
   * Mint a unique NFT
   *
   * @remarks Mint a unique NFT to a specified wallet.
   *
   * @example
   * ```javascript*
   * // Custom metadata of the NFT, note that you can fully customize this metadata with other properties.
   * const metadata = {
   *   name: "Cool NFT",
   *   description: "This is a cool NFT",
   *   image: fs.readFileSync("path/to/image.png"), // This can be an image url or file
   * };
   *
   * const tx = await contract.mint(metadata);
   * const receipt = tx.receipt; // the transaction receipt
   * const tokenId = tx.id; // the id of the NFT minted
   * const nft = await tx.data(); // (optional) fetch details of minted NFT
   * ```
   */


  async mint(metadata) {
    return this.erc721.mint(metadata);
  }
  /**
   * Mint a unique NFT
   *
   * @remarks Mint a unique NFT to a specified wallet.
   *
   * @example
   * ```javascript
   * // Address of the wallet you want to mint the NFT to
   * const walletAddress = "{{wallet_address}}";
   *
   * // Custom metadata of the NFT, note that you can fully customize this metadata with other properties.
   * const metadata = {
   *   name: "Cool NFT",
   *   description: "This is a cool NFT",
   *   image: fs.readFileSync("path/to/image.png"), // This can be an image url or file
   * };
   *
   * const tx = await contract.mintTo(walletAddress, metadata);
   * const receipt = tx.receipt; // the transaction receipt
   * const tokenId = tx.id; // the id of the NFT minted
   * const nft = await tx.data(); // (optional) fetch details of minted NFT
   * ```
   */


  async mintTo(walletAddress, metadata) {
    return this.erc721.mintTo(walletAddress, metadata);
  }
  /**
   * Mint Many unique NFTs
   *
   * @remarks Mint many unique NFTs at once to the connected wallet
   *
   * @example
   * ```javascript*
   * // Custom metadata of the NFTs you want to mint.
   * const metadatas = [{
   *   name: "Cool NFT #1",
   *   description: "This is a cool NFT",
   *   image: fs.readFileSync("path/to/image.png"), // This can be an image url or file
   * }, {
   *   name: "Cool NFT #2",
   *   description: "This is a cool NFT",
   *   image: fs.readFileSync("path/to/other/image.png"),
   * }];
   *
   * const tx = await contract.mintBatch(metadatas);
   * const receipt = tx[0].receipt; // same transaction receipt for all minted NFTs
   * const firstTokenId = tx[0].id; // token id of the first minted NFT
   * const firstNFT = await tx[0].data(); // (optional) fetch details of the first minted NFT
   * ```
   */


  async mintBatch(metadata) {
    return this.erc721.mintBatch(metadata);
  }
  /**
   * Mint Many unique NFTs
   *
   * @remarks Mint many unique NFTs at once to a specified wallet.
   *
   * @example
   * ```javascript
   * // Address of the wallet you want to mint the NFT to
   * const walletAddress = "{{wallet_address}}";
   *
   * // Custom metadata of the NFTs you want to mint.
   * const metadatas = [{
   *   name: "Cool NFT #1",
   *   description: "This is a cool NFT",
   *   image: fs.readFileSync("path/to/image.png"), // This can be an image url or file
   * }, {
   *   name: "Cool NFT #2",
   *   description: "This is a cool NFT",
   *   image: fs.readFileSync("path/to/other/image.png"),
   * }];
   *
   * const tx = await contract.mintBatchTo(walletAddress, metadatas);
   * const receipt = tx[0].receipt; // same transaction receipt for all minted NFTs
   * const firstTokenId = tx[0].id; // token id of the first minted NFT
   * const firstNFT = await tx[0].data(); // (optional) fetch details of the first minted NFT
   * ```
   */


  async mintBatchTo(walletAddress, metadata) {
    return this.erc721.mintBatchTo(walletAddress, metadata);
  }
  /**
   * Burn a single NFT
   * @param tokenId - the token Id to burn
   *
   * @example
   * ```javascript
   * const result = await contract.burnToken(tokenId);
   * ```
   */


  async burn(tokenId) {
    return this.erc721.burn(tokenId);
  }
  /**
   * @internal
   */


  async call(functionName) {
    for (var _len = arguments.length, args = new Array(_len > 1 ? _len - 1 : 0), _key = 1; _key < _len; _key++) {
      args[_key - 1] = arguments[_key];
    }

    return this.contractWrapper.call(functionName, ...args);
  }

}

_defineProperty(NFTCollection, "contractRoles", ["admin", "minter", "transfer"]);

export { NFTCollection };
