import { _ as _defineProperty } from './QueryParams-536ff1cc.esm.js';
import { au as StandardErc20, cm as ContractWrapper, ag as ContractMetadata, cK as TokenErc20ContractSchema, ah as ContractRoles, aj as ContractPrimarySale, aR as ContractEvents, ar as TokenERC20History, af as ContractEncoder, aQ as GasCostEstimator, aT as ContractPlatformFee, aS as ContractInterceptor, as as Erc20SignatureMintable, br as getRoleHash } from './paper-xyz-9928d271.esm.js';
import { constants } from 'ethers';
import 'bn.js';
import 'zod';
import '@weiweb3/contracts-js/dist/abis/IERC165.json';
import '@weiweb3/contracts-js/dist/abis/IERC721.json';
import '@weiweb3/contracts-js/dist/abis/IERC1155.json';
import 'tiny-invariant';
import 'eventemitter3';
import 'cross-fetch';
import '@weiweb3/contracts-js/dist/abis/Forwarder.json';
import '@weiweb3/contracts-js/dist/abis/IBurnableERC20.json';
import '@weiweb3/contracts-js/dist/abis/IDropSinglePhase.json';
import '@weiweb3/contracts-js/dist/abis/IERC20.json';
import '@weiweb3/contracts-js/dist/abis/IMintableERC20.json';
import '@weiweb3/contracts-js/dist/abis/IMulticall.json';
import '@weiweb3/contracts-js/dist/abis/ISignatureMintERC20.json';
import '@weiweb3/contracts-js/dist/abis/IBurnableERC721.json';
import '@weiweb3/contracts-js/dist/abis/IClaimableERC721.json';
import '@weiweb3/contracts-js/dist/abis/IDelayedReveal.json';
import '@weiweb3/contracts-js/dist/abis/IERC721Enumerable.json';
import '@weiweb3/contracts-js/dist/abis/IERC721Supply.json';
import '@weiweb3/contracts-js/dist/abis/ILazyMint.json';
import '@weiweb3/contracts-js/dist/abis/IMintableERC721.json';
import '@weiweb3/contracts-js/dist/abis/SignatureMintERC721.json';
import '@weiweb3/contracts-js/dist/abis/DelayedReveal.json';
import '@weiweb3/contracts-js/dist/abis/DropSinglePhase1155.json';
import '@weiweb3/contracts-js/dist/abis/IBurnableERC1155.json';
import '@weiweb3/contracts-js/dist/abis/IClaimableERC1155.json';
import '@weiweb3/contracts-js/dist/abis/IERC1155Enumerable.json';
import '@weiweb3/contracts-js/dist/abis/IMintableERC1155.json';
import '@weiweb3/contracts-js/dist/abis/ISignatureMintERC1155.json';
import 'bs58';
import 'cbor-x';
import '@weiweb3/contracts-js/dist/abis/IERC20Metadata.json';
import 'merkletreejs';
import 'fast-deep-equal';
import 'uuid';
import '@weiweb3/contracts-js/dist/abis/IERC721Metadata.json';
import '@weiweb3/contracts-js/dist/abis/IERC1155Metadata.json';
import '@weiweb3/contracts-js/dist/abis/IDelayedRevealDeprecated.json';
import '@weiweb3/contracts-js/dist/abis/TWFactory.json';
import '@weiweb3/contracts-js/dist/abis/TWRegistry.json';
import '@weiweb3/contracts-js/dist/abis/ContractPublisher.json';
import '@weiweb3/contracts-js/dist/abis/IWeiweb3Contract.json';
import '@weiweb3/storage';
import '@weiweb3/contracts-js/dist/abis/IAppURI.json';
import '@weiweb3/contracts-js/dist/abis/IContractMetadata.json';
import '@weiweb3/contracts-js/dist/abis/IPermissions.json';
import '@weiweb3/contracts-js/dist/abis/IPermissionsEnumerable.json';
import '@weiweb3/contracts-js/dist/abis/IPlatformFee.json';
import '@weiweb3/contracts-js/dist/abis/IPrimarySale.json';
import '@weiweb3/contracts-js/dist/abis/IRoyalty.json';
import '@weiweb3/contracts-js/dist/abis/Ownable.json';

/**
 * Create a standard crypto token or cryptocurrency.
 *
 * @example
 *
 * ```javascript
 * import { Weiweb3SDK } from "@weiweb3/sdk";
 *
 * const sdk = new Weiweb3SDK("{{chainName}}");
 * const contract = sdk.getContract("{{contract_address}}", "token");
 * ```
 *
 * @public
 */

class Token extends StandardErc20 {
  /**
   * Signature Minting
   * @remarks Generate tokens that can be minted only with your own signature, attaching your own set of mint conditions.
   * @example
   * ```javascript
   * // see how to craft a payload to sign in the `contract.signature.generate()` documentation
   * const signedPayload = contract.signature.generate(payload);
   *
   * // now anyone can mint the tokens
   * const tx = contract.signature.mint(signedPayload);
   * const receipt = tx.receipt; // the mint transaction receipt
   * ```
   */

  /**
   * @internal
   */
  constructor(network, address, storage) {
    let options = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : {};
    let abi = arguments.length > 4 ? arguments[4] : undefined;
    let chainId = arguments.length > 5 ? arguments[5] : undefined;
    let contractWrapper = arguments.length > 6 && arguments[6] !== undefined ? arguments[6] : new ContractWrapper(network, address, abi, options);
    super(contractWrapper, storage, chainId);

    _defineProperty(this, "abi", void 0);

    _defineProperty(this, "metadata", void 0);

    _defineProperty(this, "roles", void 0);

    _defineProperty(this, "encoder", void 0);

    _defineProperty(this, "estimator", void 0);

    _defineProperty(this, "history", void 0);

    _defineProperty(this, "events", void 0);

    _defineProperty(this, "platformFees", void 0);

    _defineProperty(this, "sales", void 0);

    _defineProperty(this, "signature", void 0);

    _defineProperty(this, "interceptor", void 0);

    this.abi = abi;
    this.metadata = new ContractMetadata(this.contractWrapper, TokenErc20ContractSchema, this.storage);
    this.roles = new ContractRoles(this.contractWrapper, Token.contractRoles);
    this.sales = new ContractPrimarySale(this.contractWrapper);
    this.events = new ContractEvents(this.contractWrapper);
    this.history = new TokenERC20History(this.contractWrapper, this.events);
    this.encoder = new ContractEncoder(this.contractWrapper);
    this.estimator = new GasCostEstimator(this.contractWrapper);
    this.platformFees = new ContractPlatformFee(this.contractWrapper);
    this.interceptor = new ContractInterceptor(this.contractWrapper);
    this.signature = new Erc20SignatureMintable(this.contractWrapper, this.roles);
  }
  /** ******************************
   * READ FUNCTIONS
   *******************************/

  /**
   * Get your wallet voting power for the current checkpoints
   *
   * @returns the amount of voting power in tokens
   */


  async getVoteBalance() {
    return await this.getVoteBalanceOf(await this.contractWrapper.getSignerAddress());
  }

  async getVoteBalanceOf(account) {
    return await this.erc20.getValue(await this.contractWrapper.readContract.getVotes(account));
  }
  /**
   * Get your voting delegatee address
   *
   * @returns the address of your vote delegatee
   */


  async getDelegation() {
    return await this.getDelegationOf(await this.contractWrapper.getSignerAddress());
  }
  /**
   * Get a specific address voting delegatee address
   *
   * @returns the address of your vote delegatee
   */


  async getDelegationOf(account) {
    return await this.contractWrapper.readContract.delegates(account);
  }
  /**
   * Get whether users can transfer tokens from this contract
   */


  async isTransferRestricted() {
    const anyoneCanTransfer = await this.contractWrapper.readContract.hasRole(getRoleHash("transfer"), constants.AddressZero);
    return !anyoneCanTransfer;
  }
  /** ******************************
   * WRITE FUNCTIONS
   *******************************/

  /**
   * Mint Tokens for the connected wallet
   *
   * @remarks See {@link Token.mintTo}
   */


  async mint(amount) {
    return this.erc20.mint(amount);
  }
  /**
   * Mint Tokens
   *
   * @remarks Mint tokens to a specified address.
   *
   * @example
   * ```javascript
   * const toAddress = "{{wallet_address}}"; // Address of the wallet you want to mint the tokens to
   * const amount = "1.5"; // The amount of this token you want to mint
   *
   * await contract.mintTo(toAddress, amount);
   * ```
   */


  async mintTo(to, amount) {
    return this.erc20.mintTo(to, amount);
  }
  /**
   * Mint Tokens To Many Wallets
   *
   * @remarks Mint tokens to many wallets in one transaction.
   *
   * @example
   * ```javascript
   * // Data of the tokens you want to mint
   * const data = [
   *   {
   *     toAddress: "{{wallet_address}}", // Address to mint tokens to
   *     amount: 0.2, // How many tokens to mint to specified address
   *   },
   *  {
   *    toAddress: "0x...",
   *    amount: 1.4,
   *  }
   * ]
   *
   * await contract.mintBatchTo(data);
   * ```
   */


  async mintBatchTo(args) {
    return this.erc20.mintBatchTo(args);
  }
  /**
   * Lets you delegate your voting power to the delegateeAddress
   *
   * @param delegateeAddress - delegatee wallet address
   * @alpha
   */


  async delegateTo(delegateeAddress) {
    return {
      receipt: await this.contractWrapper.sendTransaction("delegate", [delegateeAddress])
    };
  }
  /**
   * Burn Tokens
   *
   * @remarks Burn tokens held by the connected wallet
   *
   * @example
   * ```javascript
   * // The amount of this token you want to burn
   * const amount = 1.2;
   *
   * await contract.burnTokens(amount);
   * ```
   */


  async burn(amount) {
    return this.erc20.burn(amount);
  }
  /**
   * Burn Tokens
   *
   * @remarks Burn tokens held by the specified wallet
   *
   * @example
   * ```javascript
   * // Address of the wallet sending the tokens
   * const holderAddress = "{{wallet_address}}";
   *
   * // The amount of this token you want to burn
   * const amount = 1.2;
   *
   * await contract.burnFrom(holderAddress, amount);
   * ```
   */


  async burnFrom(holder, amount) {
    return this.erc20.burnFrom(holder, amount);
  }
  /**
   * @internal
   */


  async call(functionName) {
    for (var _len = arguments.length, args = new Array(_len > 1 ? _len - 1 : 0), _key = 1; _key < _len; _key++) {
      args[_key - 1] = arguments[_key];
    }

    return this.contractWrapper.call(functionName, ...args);
  }

}

_defineProperty(Token, "contractRoles", ["admin", "minter", "transfer"]);

export { Token };
